﻿using System;
using System.Configuration;

namespace Niche.GroupInspector.Configuration
{
    public class GroupCollection : ConfigurationElementCollection
    {
                /// <summary>
        /// Initializes a new instance of the <see cref="ApplicationSystemsCollection"/> class.
        /// </summary>
        public GroupCollection()
        {
            // Nothing
        }

        /// <summary>
        /// Gets the type of instance contained by the collection
        /// </summary>
        public override ConfigurationElementCollectionType CollectionType
        {
            get
            {
                return ConfigurationElementCollectionType.AddRemoveClearMap;
            }
        }

        /// <summary>
        /// Create a new element to add to this collection
        /// </summary>
        /// <returns>New instance.</returns>
        protected override ConfigurationElement CreateNewElement()
        {
            return new GroupSettings();
        }

        /// <summary>
        /// Create a new element with a specified name
        /// </summary>
        /// <param name="elementName">Name to use for the new item</param>
        /// <returns>New instance.</returns>
        protected override ConfigurationElement CreateNewElement(string elementName)
        {
            return new GroupSettings()
                       {
                           Name = elementName
                       };
        }


        protected override Object GetElementKey(ConfigurationElement element)
        {
            return ((GroupSettings)element).Name;
        }


        public new string AddElementName
        {
            get
            {
                return base.AddElementName;
            }

            set
            {
                base.AddElementName = value;
            }
        }

        public new string ClearElementName
        {
            get
            {
                return base.ClearElementName;
            }

            set
            {
                base.AddElementName = value;
            }
        }

        public new string RemoveElementName
        {
            get
            {
                return base.RemoveElementName;
            }
        }

        public new int Count
        {
            get
            {
                return base.Count;
            }
        }

        /// <summary>
        /// Gets or sets system settings in this collection
        /// </summary>
        /// <param name="index">Index of access</param>
        public GroupSettings this[int index]
        {
            get
            {
                return (GroupSettings)BaseGet(index);
            }

            set
            {
                if (BaseGet(index) != null)
                {
                    BaseRemoveAt(index);
                }

                BaseAdd(index, value);
            }
        }

        /// <summary>
        /// Gets or sets system setting in this collection
        /// </summary>
        /// <param name="name">Name of access</param>
        public new GroupSettings this[string name]
        {
            get
            {
                return (GroupSettings)BaseGet(name);
            }
        }

        public int IndexOf(GroupSettings group)
        {
            return BaseIndexOf(group);
        }

        public void Add(GroupSettings group)
        {
            BaseAdd(group);
        }

        protected override void BaseAdd(ConfigurationElement element)
        {
            BaseAdd(element, false);
        }

        public void Remove(GroupSettings group)
        {
            if (BaseIndexOf(group) >= 0)
            {
                BaseRemove(group.Name);
            }
        }

        public void RemoveAt(int index)
        {
            BaseRemoveAt(index);
        }

        public void Remove(string name)
        {
            BaseRemove(name);
        }

        public void Clear()
        {
            BaseClear();
        }

    }
}
