﻿using System.Collections.Generic;
using Niche.GroupInspector.Domain;

namespace Niche.GroupInspector.Presentation
{
    public interface IGroupInspectorView
    {
        /// <summary>
        /// Gets or sets a reference to this Views Presenter
        /// </summary>
        IGroupInspectorPresenter Presenter
        {
            get;
            set;
        }

        /// <summary>
        /// Set the Application Systems available for selection by the User
        /// </summary>
        /// <param name="systems">Sequence of available systems</param>
        void SetAvailableSystems(IEnumerable<ApplicationSystem> systems);

        /// <summary>
        /// Display a set of access groups
        /// </summary>
        /// Should add the group to the display, retaining any existing display
        /// <param name="groups">Group to display</param>
        /// <param name="users">Users found in group</param>
        void DisplayAccessGroups(IEnumerable<AccessGroup> groups);

        /// <summary>
        /// Display an error message to the user
        /// </summary>
        /// <param name="errorMessage">Message to display</param>
        /// <param name="toolTip">Additional information to display as a tooltip</param>
        void DisplayError(string errorMessage, string toolTip);

        /// <summary>
        /// Display progress update to the user
        /// </summary>
        /// <param name="progressMessage">Message to display</param>
        /// <param name="completed">Number of completed steps</param>
        /// <param name="total">Number of steps in total</param>
        void DisplayProgress(string progressMessage, int completed, int total);

        /// <summary>
        /// Configure display to a particular style
        /// </summary>
        /// <param name="viewStyle">Style of view to configure</param>
        void SetViewStyle(ViewStyle style);
    }
}